# cgkmc

[![Custom shields.io](https://img.shields.io/badge/docs-brightgreen?logo=github&logoColor=green&label=gh-pages)](https://jwjeffr.github.io/cgkmc/)

[![PyPI version shields.io](https://img.shields.io/pypi/v/cgkmc.svg)](https://pypi.python.org/pypi/cgkmc/)
[![PyPI pyversions shields.io](https://img.shields.io/pypi/pyversions/cgkmc.svg)](https://pypi.python.org/pypi/cgkmc/)

## 💎 What is cgkmc?

`cgkmc` is a package for performing crystal growth simulations using the 
[Kinetic Monte Carlo](https://en.wikipedia.org/wiki/Kinetic_Monte_Carlo) method. `cgkmc`'s namesake is shorthand for
Crystal Growth Kinetic Monte Carlo.

## 📥 Installation

```bash
pip install cgkmc
```

## 📃 License

`cgkmc` is released under the MIT License.

## 🔖 Citing

If you found this package useful, please cite our work on arXiv:

```
@misc{cgkmc,
      title={Kinetic Monte Carlo prediction of the morphology of pentaerythritol tetranitrate}, 
      author={Jacob Jeffries and Himanshu Singh and Romain Perriot and Christian Negre and Antonio Redondo and Enrique Martinez},
      year={2025},
      eprint={2509.25490},
      archivePrefix={arXiv},
      primaryClass={cond-mat.mtrl-sci},
      url={https://arxiv.org/abs/2509.25490}, 
}
```

## ❤️ Acknowledgements

This work was supported by the Laboratory Directed Research and Development program of Los Alamos National Laboratory 
under project no. 20220431ER. This research used resources provided by the Los Alamos National Laboratory Institutional 
Computing Program. Los Alamos National Laboratory is operated by Triad National Security, LLC, for the National Nuclear 
Security Administration of U.S. Department of Energy (contract no. 89233218CNA000001).

Additionally, this material is based on work supported by the National Science Foundation under Grant Nos. 
MRI# 2024205, MRI# 1725573, and CRI# 2010270 for allotment of compute time on the Clemson University Palmetto Cluster.